@@ -462,7 +462,7 @@ test_that('latex handles multiple newline',{
   'one \njoule \n(Omega) ~\n 1 kg*m^2./s^2'%>% render
   expect_identical(
     '1\\n2\\n3\\n4\\n' %>% as_spork %>% as_latex %>% as.character,
-    "\\(\\mathrm{\\textrm{1}\n \\textrm{2}\n \\textrm{3}\n \\textrm{4}\n}\\)"
+    "\\(\\mathrm{\\textrm{1}}\\)\n\\(\\mathrm{\\textrm{2}}\\)\n\\(\\mathrm{\\textrm{3}}\\)\n\\(\\mathrm{\\textrm{4}}\\)\n"
   )
 })
 test_that('plotmath handles multiple newline',{
@@ -641,3 +641,6 @@ test_that('sub/super are written smaller', {
   )
   
 })
+test_that('explicit is stable', {
+  expect_equal_to_reference(file = '001.rds', explicit(as_spork('AUC_inf\\nx^y\\n')))
+})
